@@ -2,7 +2,7 @@ use v5.10.0;
 
 package JMAP::Tester::Response;
 # ABSTRACT: what you get in reply to a succesful JMAP request
-$JMAP::Tester::Response::VERSION = '0.002';
+$JMAP::Tester::Response::VERSION = '0.003';
 use Moo;
 with 'JMAP::Tester::Role::Result';
 
@@ -27,6 +27,10 @@ has struct => (
   required => 1,
 );
 
+has http_response => (
+  is       => 'ro',
+);
+
 has _json_typist => (
   is => 'ro',
   handles => {
@@ -280,7 +284,7 @@ JMAP::Tester::Response - what you get in reply to a succesful JMAP request
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 OVERVIEW
 
